@@ -9,8 +9,10 @@ to deal in the Software without restriction, including without limitation
 the rights to use, copy, modify, merge, publish, distribute, sublicense,
 and/or sell copies of the Software, and to permit persons to whom the
 Software is furnished to do so, subject to the following conditions:
+
 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.
+
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -24,9 +26,8 @@ __title__ = 'imgbbpy'
 __author__ = 'scrazzz'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2021 scrazzz'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
-from .imgbb import AsyncClient, SyncClient
+from .imgbb import *
 from .imgerrors import *
-from .imggallery import Image
-
+from .imggallery import *
