@@ -9,8 +9,10 @@ to deal in the Software without restriction, including without limitation
 the rights to use, copy, modify, merge, publish, distribute, sublicense,
 and/or sell copies of the Software, and to permit persons to whom the
 Software is furnished to do so, subject to the following conditions:
+
 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.
+
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -26,44 +28,47 @@ from base64 import b64encode
 import aiohttp
 import requests
 
-from .imgerrors import ImgbbError, MaxExpirationLimit, MinExpirationLimit
-from .imggallery import Image
+from .imgerrors import *
+from .imggallery import *
 
-API_URL = 'https://api.imgbb.com/1/upload'
+_API_URL = 'https://api.imgbb.com/1/upload'
 
 class AsyncClient:
     """Represents an asynchronous client connection that connects to the Imgbb API for uploading.
-    
+ 
     Parameters
     ----------
     key: str
         The API Key required to make a connection with the API.
-    
+
     Methods
     -------
     upload(*, url=None, file=None, name="", expiration=None)
         Uploads the image.
+    
+    close()
+        Closes the Client Session.
     """
 
-    def __init__(self, key: str):
+    def __init__(self, key: str) -> None:
         self.key = key
         self._session = aiohttp.ClientSession()
-    
+
     async def upload(
         self,
         *,
         url: str = None,
         file: str = None,
-        name: str = "",
+        name: str = "image",
         expiration: int = None
-    ):
-        """
-        Uploads the image.
+    ) -> Image:
+        """Uploads the image.
 
         Note
         -----
         * Both `url` and `file` are optional, but either `url` or `file` is required for uploading the image.
         * The image to upload should not be more than 32 MB.
+        * Image gets deleted automatically after 2592000 seconds (30 days) by default. 
 
         Parameters
         ----------
@@ -119,22 +124,9 @@ class AsyncClient:
                 raise MaxExpirationLimit('Maximum expiration limit is 15552000 seconds.')
 
         if file:
-            if expiration:
-                params = {
-                    'key': self.key,
-                    'name': name,
-                    'expiration': str(expiration)
-                }
-            elif expiration is None:
-                params = {
-                    'key': self.key,
-                    'name': name
-                }
             data = {
                 'image': open(file, 'rb')
             }
-
-        if url:
             if expiration:
                 params = {
                     'key': self.key,
@@ -146,29 +138,46 @@ class AsyncClient:
                     'key': self.key,
                     'name': name
                 }
+
+        if url:
             data = {
                 'image': url
             }
-        async with self._session as session:
-            async with session.post(API_URL, params=params, data=data) as post:
-                js = await post.json()
-                
-                if post.status == 200:
-                    data = js['data']
-                    return Image(
-                        title = data['title'],
-                        url = data['url'],
-                        display_url = data['display_url'],
-                        size = data['size'],
-                        mime = data['image']['mime'],
-                        extension = data['image']['extension'],
-                        delete_url = data['delete_url']
-                    )
-                else:
-                    raise ImgbbError(f"Error {js['status_code']}: {js['error']['message']}")
+            if expiration:
+                params = {
+                    'key': self.key,
+                    'name': name,
+                    'expiration': str(expiration)
+                }
+            elif expiration is None:
+                params = {
+                    'key': self.key,
+                    'name': name
+                }
+        async with self._session.post(_API_URL, params=params, data=data) as post:
+            js = await post.json()
+            
+            if post.status == 200:
+                data = js['data']
+                return Image(
+                    id = data['id'],
+                    filename = data['image']['filename'],
+                    url = data['url'],
+                    size = data['size'],
+                    expiration = data['expiration'],
+                    mime = data['image']['mime'],
+                    extension = data['image']['extension'],
+                    delete_url = data['delete_url']
+                )
+            else:
+                raise ImgbbError(f"Error {js['status_code']}: {js['error']['message']}")
+
+    async def close(self):
+        """Closes the Client Session."""
+        await self._session.close()
 
 class SyncClient:
-    """Represents an a synchronous client connection that connects to the Imgbb API for uploading.
+    """Represents a synchronous client connection that connects to the Imgbb API for uploading.
 
     Parameters
     ----------
@@ -181,26 +190,26 @@ class SyncClient:
         Uploads the image.
     """
 
-    def __init__(self, key):
+    def __init__(self, key) -> None:
         self.key = key
         self._session = requests.Session()
-    
+ 
     def upload(
         self,
         *,
         file: str = None,
         url: str = None,
-        name: str = "",
+        name: str = "image",
         expiration: int = None
-    ):
-        """
-        Uploads the image.
-        
+    ) -> Image:
+        """Uploads the image.
+
         Note
         -----
         * Both `url` and `file` are optional, but either `url` or `file` is required for uploading the image.
         * The image to upload should not be more than 32 MB.
-        
+        * Image gets deleted automatically after 2592000 seconds (30 days) by default.
+ 
         Parameters
         ----------
         url: str, optional
@@ -211,7 +220,7 @@ class SyncClient:
             The name of the file. This is automatically set if not given.
         expiration: int, optional
             Use this if you want the uploaded image to be auto deleted after certain time (in seconds 60-15552000).
-        
+ 
         Raises
         ------
         TypeError
@@ -280,16 +289,17 @@ class SyncClient:
                     'name': name,
                     'image': url
                 }
-        r = self._session.post(API_URL, params)
+        r = self._session.post(_API_URL, params)
         js = r.json()
 
         if r.status_code == 200:
             data = js['data']
             return Image(
-                title = data['title'],
+                id = data['id'],
+                filename = data['image']['filename'],
                 url = data['url'],
-                display_url = data['display_url'],
                 size = data['size'],
+                expiration = data['expiration'],
                 mime = data['image']['mime'],
                 extension = data['image']['extension'],
                 delete_url = data['delete_url']
