@@ -9,8 +9,10 @@ to deal in the Software without restriction, including without limitation
 the rights to use, copy, modify, merge, publish, distribute, sublicense,
 and/or sell copies of the Software, and to permit persons to whom the
 Software is furnished to do so, subject to the following conditions:
+
 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.
+
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -21,16 +23,10 @@ DEALINGS IN THE SOFTWARE.
 """
 
 class ImgbbError(Exception):
-    """
-    Base exception for all errors.
-    """
+    """Base exception for all imgbbpy errors."""
 
 class MaxExpirationLimit(ImgbbError):
-    """
-    Exception for max expiration limit.
-    """
+    """Exception for maximum expiration limit."""
 
 class MinExpirationLimit(ImgbbError):
-    """
-    Exception for min expiration limit.
-    """
+    """Exception for minimum expiration limit."""
